@@ -100,8 +100,8 @@ createGraphFromHommelEtAl <- function() {
 			n2 <- hnodes[3+j]
 			graph <- addEdge(n1, n2, graph, 1/3)
 			edgeData(graph, n1, n2, "epsilon") <- list(-2/3)	
-			x <- ((i+j)*200-200)/2+sign(i-j)*20
-			y <- 300 + (abs(i-j)*45)+sign(i-j)*5		
+			x <- ((i+j)*200-200)/2+sign(i-j)*30
+			y <- 300 + ((abs(i-j)-1)*60)+sign(i-j)*10+10
 			edgeData(graph, n1, n2, "labelX") <- x
 			edgeData(graph, n1, n2, "labelY") <- y
 		}
