@@ -1,8 +1,13 @@
 graph2latex <- function(graph, package="TikZ", scale=1, alpha=0.05, pvalues,
 		fontsize=c("tiny","scriptsize", "footnotesize", "small",
 		"normalsize", "large", "Large", "LARGE", "huge", "Huge"),
-		nodeTikZ) {
-	tikz <- paste("\\begin{tikzpicture}[scale=",scale,"]", sep="")	
+		nodeTikZ, labelTikZ="near start,above,fill=blue!20",
+		tikzEnv=TRUE, offset=c(0,0)) {
+	if (tikzEnv) {
+		tikz <- paste("\\begin{tikzpicture}[scale=",scale,"]", sep="")
+	} else {
+		tikz <- ""
+	}
 	#tikz <- paste(tikz, "\\tikzset{help lines/.style=very thin}", paste="\n")	
 	for (node in nodes(graph)) {
 		nodeColor <- ifelse(getRejected(graph, node),"red!80", "green!80")
@@ -23,7 +28,7 @@ graph2latex <- function(graph, package="TikZ", scale=1, alpha=0.05, pvalues,
 			if (canBeRejected(graph, node, alpha, pvalues)) { double <- "double," }
 		}		
 		nodeLine <- paste("\\node (",node,")",
-				" at (",x,"bp,",-y,"bp)",
+				" at (",x+offset[1],"bp,",-y-offset[2],"bp)",
 				"[draw,circle split,",ifelse(missing(nodeTikZ),"",paste(nodeTikZ,", ",sep="")),double,"fill=",nodeColor,"]",
 				" {$",node,"$ \\nodepart{lower} $",weight,"$};",sep="")
 		tikz <- paste(tikz, nodeLine,sep="\n")			
@@ -32,16 +37,18 @@ graph2latex <- function(graph, package="TikZ", scale=1, alpha=0.05, pvalues,
 	for (node in nodes(graph)) {
 		edgeL <- edgeWeights(graph)[[node]]	
 		if (length(edgeL)!=0) {
-			for (i in 1:length(edgeL)) {
+			for (i in 1:length(edgeL)) {	
+				# The following to lines test whether the edge in opposite direction exists:
 				weight <- try(edgeData(graph, names(edgeL[i]), node,"weight"), silent = TRUE)
 				to <- ifelse(class(weight)=="try-error", "auto", "bend left=15")			
-				weight <- ifelse(edgeL[i]==0, "\\epsilon", getLaTeXFraction(edgeL[i])) # format(edgeL[i], digits=3, drop0trailing=TRUE))
-				edgeLine <- paste("\\draw [->,line width=1pt] (",node,") to[",to,"] node[near start,above,fill=blue!20] {$",weight,"$} (",names(edgeL[i]),");",sep="")
+				#weight <- ifelse(edgeL[i]==0, "\\epsilon", getLaTeXFraction(edgeL[i])) # format(edgeL[i], digits=3, drop0trailing=TRUE))
+				weight <- getWeightStr(graph, node, names(edgeL[i]), LaTeX=TRUE) 
+				edgeLine <- paste("\\draw [->,line width=1pt] (",node,") to[",to,"] node[",labelTikZ,"] {$",weight,"$} (",names(edgeL[i]),");",sep="")
 				tikz <- paste(tikz, edgeLine,sep="\n")
 			}
 		}
 	}
-	tikz <- paste(tikz, "\\end{tikzpicture}\n",sep="\n")
+	if (tikzEnv) tikz <- paste(tikz, "\\end{tikzpicture}\n",sep="\n")
 	if (!missing(fontsize)) {
 		tikz <- paste(paste("{\\", fontsize, sep=""), tikz, "}",sep="\n")
 	}
