@@ -2,7 +2,6 @@ package org.mutoss.gui.dialogs;
 
 import java.awt.event.ActionEvent;
 import java.awt.event.ActionListener;
-import java.util.Set;
 
 import javax.swing.JButton;
 import javax.swing.JDialog;
@@ -35,6 +34,7 @@ public class VariableNameDialog extends JDialog implements ActionListener {
 		int row = 2;
 
 		jt.setText(parent.getGraphView().getGraphName());
+		jt.addActionListener(this);
 		getContentPane().add(new JLabel("R object name:"), cc.xy(2, row));
 		getContentPane().add(jt, cc.xy(4, row));
 
